@@ -9,6 +9,7 @@ class UMView(object):
     def __init__(self, loader, color_mapper):
         self.loader = loader
         self.color_mapper = color_mapper
+        self.color_mapper.nan_color = bokeh.colors.RGB(0, 0, 0, a=0) 
         self.source = bokeh.models.ColumnDataSource({
                 "x": [],
                 "y": [],
@@ -16,9 +17,26 @@ class UMView(object):
                 "dh": [],
                 "image": []})
 
+        self.tooltips = [
+            ("Name", "@name"),
+            ("Value", "@image @units"),
+            ('Length', '@length'),
+            ('Valid', '@valid{%F %H:%M}'),
+            ('Initial', '@initial{%F %H:%M}'),
+            ("Level", "@level")]
+
+        self.formatters = {
+            'valid': 'datetime',
+            'initial': 'datetime'
+        }
+
     def render(self, state):
         self.source.data = self.loader.image(state)
 
+    def set_hover_properties(self, tooltips, formatters):
+        self.tooltips = tooltips
+        self.formatters = formatters
+
     def add_figure(self, figure):
         renderer = figure.image(
                 x="x",
@@ -30,17 +48,8 @@ class UMView(object):
                 color_mapper=self.color_mapper)
         tool = bokeh.models.HoverTool(
                 renderers=[renderer],
-                tooltips=[
-                    ("Name", "@name"),
-                    ("Value", "@image @units"),
-                    ('Length', '@length'),
-                    ('Valid', '@valid{%F %H:%M}'),
-                    ('Initial', '@initial{%F %H:%M}'),
-                    ("Level", "@level")],
-                formatters={
-                    'valid': 'datetime',
-                    'initial': 'datetime'
-                })
+                tooltips=self.tooltips,
+                formatters=self.formatters)
         figure.add_tools(tool)
         return renderer
 
@@ -97,7 +106,6 @@ class EIDA50(object):
                 self.empty)
 
     def render(self, state):
-        print(state)
         if state.valid_time is not None:
             self.image(self.to_datetime(state.valid_time))
 
@@ -116,7 +124,6 @@ class EIDA50(object):
             raise Exception("Unknown value: {}".format(d))
 
     def image(self, time):
-        print("EIDA50: {}".format(time))
         try:
             self.source.data = self.loader.image(time)
         except (FileNotFound, IndexNotFound):
@@ -131,3 +138,40 @@ class EIDA50(object):
                 image="image",
                 source=self.source,
                 color_mapper=self.color_mapper)
+
+class NearCast(object):
+    def __init__(self, loader, color_mapper):
+        self.loader = loader
+        self.color_mapper = color_mapper
+        self.color_mapper.nan_color = bokeh.colors.RGB(0, 0, 0, a=0) 
+        self.source = bokeh.models.ColumnDataSource({
+                "x": [],
+                "y": [],
+                "dw": [],
+                "dh": [],
+                "image": []})
+                
+    def render(self, state):
+        self.source.data = self.loader.image(state)
+
+    def set_hover_properties(self, tooltips):
+        self.tooltips = tooltips
+
+    def add_figure(self, figure):
+        renderer = figure.image(
+                   x="x",
+                   y="y",
+                   dw="dw",
+                   dh="dh",
+                   image="image",
+                   source=self.source,
+                   color_mapper=self.color_mapper)
+
+        tool = bokeh.models.HoverTool(
+               renderers=[renderer],
+               tooltips=self.tooltips)
+
+        figure.add_tools(tool)
+
+        return renderer
+
